/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.2 Baustellensimulation
 * Copyright (C) 2007 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.simbaustelle.simbaustelle;

import com.bitctrl.Constants;

import de.bsvrz.ibv.simbaustelle.verwaltung.BaustellenDatenSchnittstelle;

/**
 * Standardtestdatensatz für eine Testbaustelle.<br>
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public class TestBaustellenDaten implements BaustellenDatenSchnittstelle {

	/**
	 * der Faktor für den Q0-Wert aus dem Fundamentaldiagrmm entsprechend
	 * Testkonfiguration.
	 */
	private static final double TEST_Q0_FAKTOR = 0.5;

	/**
	 * der Q0-Wert aus dem Fundamentaldiagrmm entsprechend Testkonfiguration.
	 */
	private static final long TEST_Q0_WERT = 998L;

	/**
	 * der Endzeitpunkt der Baustelle (die Testberechung erfolgt im Zeitraum
	 * 0..48).
	 */
	private static final long TEST_BST_ENDE_ZEIT = 44L;

	/**
	 * der Anfangszeitpunkt der Baustelle (die Testberechung erfolgt im Zeitraum
	 * 0..48).
	 */
	private static final long TEST_BST_START_ZEIT = 10L;

	/**
	 * die angenommene Restkapazität der Baustelle entsprechend
	 * Testspezifikation.
	 */
	private static final long TEST_RESTKAPAZITAET = 451L;

	/**
	 * der Startzeitpunkt.
	 */

	private long start;
	/**
	 * der Endzeitpunkt.
	 */
	private long ende = Long.MAX_VALUE;

	/**
	 * Die genaue Lage der Baustelle spielt hier keine Rolle, deshalb wird hier
	 * immer der Wert 0 geliefert.
	 */
	@Override
	public final long getAnfangsOffset() {
		return 0;
	}

	@Override
	public final long getEnde() {
		return ende;
	}

	/**
	 * Die genaue Lage der Baustelle spielt hier keine Rolle, deshalb wird hier
	 * immer der Wert 0 geliefert.
	 */
	@Override
	public final long getEndOffset() {
		return 0;
	}

	/**
	 * Die Prüfung der Stauberechnung erfolgt mit einem relaiven Zeitstempel von
	 * 0 beginnend. Für die Zeit, in der die Baustelle aktiv ist wird der
	 * konstante Wert 451 als Restkapazität geliefert.<br>
	 * Für alle anderen Zeitpunkte 50 Prozent vom Q0-Wert (998) des angenommenen
	 * Fundamentaldiagramms.
	 */
	@Override
	public final long getRestKapazitaet(final long zs) {
		final long stunde = zs / Constants.MILLIS_PER_HOUR;
		long result = TestBaustellenDaten.TEST_RESTKAPAZITAET;

		if ((stunde < TestBaustellenDaten.TEST_BST_START_ZEIT) || (stunde >= TestBaustellenDaten.TEST_BST_ENDE_ZEIT)) {
			result = (long) (TestBaustellenDaten.TEST_Q0_WERT * TestBaustellenDaten.TEST_Q0_FAKTOR);
		}
		return result;
	}

	@Override
	public final long getStart() {
		return start;
	}

	/**
	 * setzt die Anfangszeit der Baustelle.
	 *
	 * @param zeitPunkt
	 *            der Zeitpunkt
	 */
	public final void setAnfang(final long zeitPunkt) {
		start = zeitPunkt;

	}

	/**
	 * setzt die Endzeit der Baustelle.
	 *
	 * @param zeitPunkt
	 *            der Zeitpunkt
	 */
	public final void setEnde(final long zeitPunkt) {
		ende = zeitPunkt;
	}
}
